@@ -4,12 +4,12 @@ package JSON::Schema::Draft201909::Vocabulary::Core;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Implementation of the JSON Schema Draft 2019-09 Core vocabulary
 
-our $VERSION = '0.019';
+our $VERSION = '0.020';
 
 use 5.016;
 no if "$]" >= 5.031009, feature => 'indirect';
 no if "$]" >= 5.033001, feature => 'multidimensional';
-use JSON::Schema::Draft201909::Utilities qw(is_type abort assert_keyword_type canonical_schema_uri E);
+use JSON::Schema::Draft201909::Utilities qw(is_type abort assert_keyword_type canonical_schema_uri E assert_uri_ref);
 use Moo;
 use strictures 2;
 use namespace::clean;
@@ -129,6 +129,7 @@ sub _eval_keyword_recursiveAnchor {
 sub _traverse_keyword_ref {
   my ($self, $schema, $state) = @_;
   return if not assert_keyword_type($state, $schema, 'string');
+  return if not assert_uri_ref($state, $schema);
 }
 
 sub _eval_keyword_ref {
@@ -153,6 +154,7 @@ sub _eval_keyword_ref {
 sub _traverse_keyword_recursiveRef {
   my ($self, $schema, $state) = @_;
   return if not assert_keyword_type($state, $schema, 'string');
+  return if not assert_uri_ref($state, $schema);
 }
 
 sub _eval_keyword_recursiveRef {
@@ -186,7 +188,7 @@ sub _traverse_keyword_vocabulary {
   return if not assert_keyword_type($state, $schema, 'object');
 
   foreach my $property (sort keys %{$schema->{'$vocabulary'}}) {
-    E($state, '$vocabulary/'.$property.' value is not a boolean')
+    E($state, '$vocabulary/%s value is not a boolean', $property)
       if not is_type('boolean', $schema->{'$vocabulary'}{$property});
   }
 
@@ -225,7 +227,7 @@ JSON::Schema::Draft201909::Vocabulary::Core - Implementation of the JSON Schema
 
 =head1 VERSION
 
-version 0.019
+version 0.020
 
 =head1 DESCRIPTION
 
